/* This is "rod4.c", written to accompany Introduction to
   Scientific Programming by Joseph L. Zachary. */

/* This program is an implementation and driver for the
   "threeRodY" function described in Chapter 13 of the text. */


#include <math.h>
#include <stdio.h>



/* Returns the square of "x". */

double sq (double x)
{
  return(x*x);
}



/* Given the lengths of three sides of a triangle, returns
   the cosine of the angle between the first two. */

double cosine (double adj1, double adj2, double opp)
{
  return((sq(adj1) + sq(adj2) - sq(opp)) / (2*adj1*adj2));
}



/* Returns the distance between the points (x1,y1)
   and (x2,y2). */

double distance (double x1, double y1,
                 double x2, double y2)
{
  return(sqrt(sq(x1-x2) + sq(y1-y2)));
}



/* This function returns the y-coordinate of a circular
   rod of radius "rTop" that is suported by two other rods.
   The left supporting rod has radius "rLeft" and its center
   is at (xLeft,yLeft).  The right supporting rod has
   radius "rRight" and its center is at (xRight,yRight). */

double threeRodY (double xLeft, double yLeft,
                  double xRight, double yRight,
                  double rLeft, double rRight, double rTop)
{

  double a, b, c, d, e;   /* Sides of the two triangles from */
                          /* Figure 13.3 of the book. */

  double cosA, sinA,      /* Cosine and sine of angle alpha */
                          /* from Figure 13.3 of the book. */

         cosB, sinB;      /* Cosine and sine of angle beta */
                          /* from Figure 13.3 of the book. */


  /* Calculate the lengths of the sides of the triangles. */

  a = rLeft + rTop;
  b = rRight + rTop;
  c = distance(xLeft, yLeft, xRight, yRight);
  d = xRight - xLeft;
  e = yRight - yLeft;


  /* Calculate the cosines and sines of alpha and beta. */

  cosA = cosine(a, c, b);
  sinA = sqrt(1 - sq(cosA));
  cosB = d/c;
  sinB = e/c;


  /* Compute and return the y-coordinate of the supported rod. */

  return(yLeft + a * (sinA*cosB + sinB*cosA));

}



/* Test driver for "threeRodY". */

void main (void)
{
  double xleft, yleft, xright, yright, rleft, rright, rtop;
  printf("Enter coordinates and radius of left rod: ");
  scanf("%lf%lf%lf", &xleft, &yleft, &rleft);
  printf("Enter coordinates and radius of right rod: ");
  scanf("%lf%lf%lf", &xright, &yright, &rright);
  printf("Enter radius of top rod: ");
  scanf("%lf", &rtop);
  printf("threeRodY(%g, %g, %g, %g, %g, %g, %g) = %g\n",
         xleft, yleft, xright, yright, rleft, rright, rtop,
         threeRodY(xleft, yleft, xright, yright, rleft, rright, rtop));
}
