(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Times New Roman", 24, L0, center, nohscroll, bold;
	fontset = subtitle, "Times New Roman", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Times New Roman", 14, L0, center, nohscroll, bold;
	fontset = section, "Times New Roman", 14, L0, bold, grayBox;
	fontset = subsection, "Times New Roman", 12, L0, bold, blackBox;
	fontset = subsubsection, "Times New Roman", 10, L0, bold, whiteBox;
	fontset = text, "Times New Roman", 12, L0;
	fontset = smalltext, "Times New Roman", 10, L0;
	fontset = input, "Courier New", 12, L0, nowordwrap, bold;
	fontset = output, "Courier New", 12, L0, nowordwrap;
	fontset = message, "Courier New", 10, L0, nowordwrap, R65535;
	fontset = print, "Courier New", 10, L0, nowordwrap;
	fontset = info, "Courier New", 10, L0, nowordwrap;
	fontset = postscript, "Courier New", 8, L0, nowordwrap;
	fontset = name, "Times New Roman", 10, L0, nohscroll, italic, B65535;
	fontset = header, "Times New Roman", 10, L0, right, nohscroll;
	fontset = footer, "Times New Roman", 10, L0, right, nohscroll;
	fontset = help, "Times New Roman", 10, L0, nohscroll;
	fontset = clipboard, "Times New Roman", 12, L0, nohscroll;
	fontset = completions, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = graphics, "Courier New", 10, L0, nowordwrap, nohscroll;
	fontset = special1, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = special2, "Times New Roman", 12, L0, center, nowordwrap, nohscroll;
	fontset = special3, "Times New Roman", 12, L0, right, nowordwrap, nohscroll;
	fontset = special4, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = special5, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = leftheader, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = leftfooter, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = reserved1, "Courier New", 10, L0, nowordwrap, nohscroll;]
:[font = subsection; inactive; ]
This notebook contains the Mathematica commands from Appendix A of 
Introduction to Scientific Programming by Joseph L. Zachary.
:[font = text; inactive; ]

(A.1)  An example of how Mathematica can automatically perform dimensional 
analysis.
:[font = input; nowordwrap; ]
72 in * 2.54 cm/in
:[font = text; inactive; ]

(A.2)  The expression from (A.1) is equivalent to this one.  This illustrates 
how, in Mathematica, the multiplication operator can be omitted.
:[font = input; nowordwrap; ]
72 * in * 2.54 * cm / in
:[font = text; inactive; ]

(A.3)  Here we see that Mathematica does dimensional analysis by combining and
 cancelling symbolic constants.  It doesn't know that one foot is 12 inches.
:[font = input; nowordwrap; ]
6 ft * 2.54 cm/in
:[font = text; inactive; ]

(A.4)   If, however, we first tell Mathematica what a foot is ...
:[font = input; nowordwrap; ]
ft = 12 in
:[font = text; inactive; ]

(A.5)  ... we obtain the simplification that we expected.
:[font = input; nowordwrap; ]
6 ft * 2.54 cm/in
:[font = text; inactive; ]

Let's clear the definition of "ft".
:[font = input; nowordwrap; ]
Clear[ft]
:[font = text; inactive; ]

(A..6)  When doing dimensional analysis, you must be careful to keep 
Mathematica's precedence rules in mind.   This expression doesn't simplify 
properly ...
:[font = input; nowordwrap; ]
360 deg / 7.2 deg * 5000. stade * 0.1575 km/stade
:[font = text; inactive; ]

(A.7)   ... until we group "7.2" and "deg" together with parentheses.
:[font = input; nowordwrap; ]
360 deg / (7.2 deg) * 5000. stade * 0.1575 km/stade
:[font = text; inactive; ]

(A.8)  Here we see that Mathematica doesn't always simplify units as much as 
might seem reasonable.  The problem here is that there are two possible ways 
to simplify the square root.
:[font = input; nowordwrap; ]
Sqrt[(2.09*10^7 ft + 66 ft)^2 - (2.09*10^7 ft)^2]
:[font = text; inactive; ]

(A.9)  This is the definition of "horizontal" from Chapter 7,
:[font = input; nowordwrap; ]
horizontal[v_, theta_, t_] := v * t * Cos[theta]
:[font = text; inactive; ]

(A.10)  this is the definition of "vertical",
:[font = input; nowordwrap; ]
vertical[v_, theta_, t_] := v * t * Sin[theta] - 1/2 * g * t^2
:[font = text; inactive; ]

(A.11)  and this is the gravitational constant, which we have defined with 
appropriate units.
:[font = input; nowordwrap; ]
g = 9.8 m/sec^2
:[font = text; inactive; ]

(A.12)  The call to "horizontal" yields a properly dimensioned result,
:[font = input; nowordwrap; ]
horizontal[100 m/sec, Pi/4., 10 sec]
:[font = text; inactive; ]

(A.13)  as does this call to "vertical".
:[font = input; nowordwrap; ]
vertical[100 m/sec, Pi/4., 10 sec]
:[font = text; inactive; ]

(A.14)  Adding a unit to Pi/4 doesn't work, however, because the built-in "Cos"
function isn't expecting it.
:[font = input; nowordwrap; ]
horizontal[100 m/sec, Pi/4. rad, 10 sec]
:[font = text; inactive; ]

(A.15)  Units don't mix well with plotting commands either, as both this 
example ...
:[font = input; nowordwrap; ]
Plot[vertical[100 m/sec, Pi/4, t],
            {t, 0 sec, 20 sec}]
:[font = text; inactive; ]

(A.16)  ... and this example illustrate.
:[font = input; nowordwrap; ]
Plot[vertical[100, Pi/4, t], {t, 0, 20}]
:[font = text; inactive; ]

(A.17)  Mathematica's "Units" package provides help with unit conversions.
:[font = input; nowordwrap; ]
Needs["Miscellaneous`Units`"]
:[font = text; inactive; ]

(A.18)  The "Convert" function requires that you spell the names of the units 
exactly as it expects.
:[font = input; nowordwrap; ]
Convert[60 Mile/Hour, Kilo Meter/Second]
:[font = text; inactive; ]

(A.19) through (A.26)  Mathematica 2.2 does not support typeset mathematics.
:[font = text; inactive; ]

(A.27)  The "ComputerArithmetic" package will allow you to experiment with 
simulated floating-point number systems.
:[font = input; nowordwrap; ]
Needs["NumericalMath`ComputerArithmetic`"]
:[font = text; inactive; ]

(A.28)  We specify trhat we wish to experiment with a base-ten system with 
two-digit mantissas and exponents that range between -1 and 1, inclusive.
:[font = input; nowordwrap; ]
SetArithmetic[2, 10, ExponentRange->{-1, 2}]
:[font = text; inactive; ]

(A.29)  In this system, 11.2 is represented by 11,
:[font = input; nowordwrap; ]
ComputerNumber[11.2]
:[font = text; inactive; ]

(A.30)  0.555 is represented by 0.56,
:[font = input; nowordwrap; ]
ComputerNumber[.555]
:[font = text; inactive; ]

(A.31)  112. causes an overflow, and
:[font = input; nowordwrap; ]
ComputerNumber[112.]
:[font = text; inactive; ]

(A.32)  0.0555 causes an underflow.
:[font = input; nowordwrap; ]
ComputerNumber[.0555]
:[font = text; inactive; ]

(A.33)  We can do arithmetic in the simulated system.  Here we find the two-
digit result of dividing 1 by 8 ...
:[font = input; nowordwrap; ]
ComputerNumber[1] / ComputerNumber[8]
:[font = text; inactive; ]

(A.34)  ... and here we find the two-digit result of multiplying 12 and 1.2.
:[font = input; nowordwrap; ]
ComputerNumber[12] * ComputerNumber[1.2]
:[font = text; inactive; ]

(A.35)  We can change to a new simulated system at any time.  Here, we specify
 that the base is ten, that there are two digits of mantissa, and that the 
exponents range from -2 to 2.
:[font = input; nowordwrap; ]
SetArithmetic[2, 10, ExponentRange->{-2, 3}]
:[font = text; inactive; ]

(A.36)  The next two expressions demonstrate that multiplication is not 
associative ...
:[font = input; nowordwrap; ]
quot1 = (ComputerNumber[14] * ComputerNumber[11]) *
          ComputerNumber[2]
:[font = text; inactive; ]

(A.37)  ... in a floating-point system.
:[font = input; nowordwrap; ]
quot2 = ComputerNumber[14] *
         (ComputerNumber[11] * ComputerNumber[2])
:[font = text; inactive; ]

(A.38)  We can use "InputForm" to learn more about a simulated floating-point 
number.
:[font = input; nowordwrap; ]
InputForm[quot1]
:[font = text; inactive; ]

(A.39)  Compare this number with the one from (A.38).
:[font = input; nowordwrap; ]
InputForm[quot2]
:[font = text; inactive; ]

(A.40)  "Arithmetic" shows us the details of the floating-point system 
currently being simulated.
:[font = input; nowordwrap; ]
Arithmetic[]
:[font = text; inactive; ]

(A.41)  This is a 30-digit arbitrary-precision number.
:[font = input; nowordwrap; ]
radius = N[1/7, 30]
:[font = text; inactive; ]

(A.42)  This is a 25-digit approximation of Pi.
:[font = input; nowordwrap; ]
pi = N[Pi, 25]
:[font = text; inactive; ]

(A.43)  This is a 25-digit approximation of Pi/49.
:[font = input; nowordwrap; ]
area = N[Pi*(1/7)^2, 25]
:[font = text; inactive; ]

(A.44)  Arbitrary-precision numbers keep track of how many digits are 
meaningful, as illustrated here,
:[font = input; nowordwrap; ]
Precision[radius]
:[font = text; inactive; ]

(A.45) and here,
:[font = input; nowordwrap; ]
Precision[pi]
:[font = text; inactive; ]

(A.46)  and here.
:[font = input; nowordwrap; ]
Precision[area]
:[font = text; inactive; ]

(A.47)  We calculate a number using a 30-digit radius and a 25-digit pi.
:[font = input; nowordwrap; ]
area = pi * radius^2
:[font = text; inactive; ]

(A.48)  The result has 25 digits.
:[font = input; nowordwrap; ]
Precision[area]
:[font = text; inactive; ]

(A.49)  Squaring a 25-digit number produces a 25-digit number.
:[font = input; nowordwrap; ]
Precision[pi^2]
:[font = text; inactive; ]

(A.50)  Digits are gradually lost as more operations are performed.
:[font = input; nowordwrap; ]
Precision[pi^4]
:[font = text; inactive; ]

(A.51)  Here, we have lost five digits from the original 25-digit precision of pi.
:[font = input; nowordwrap; ]
Precision[pi^100000]
:[font = text; inactive; ]

(A.52)  When converting a number into arbitrary-precision form, always specify
 a rational number.  Otherwise, the result will have only 16 digits of 
precision.
:[font = input; nowordwrap; ]
Precision[N[1.234, 50]]
:[font = text; inactive; ]

(A.53)  Writing an extra-long "floating-point" number ...
:[font = input; nowordwrap; ]
x = .12345678901234567890*10^20
:[font = text; inactive; ]

(A.54)  ...  is another way to create an arbitrary-precision number.
:[font = input; nowordwrap; ]
Precision[x]
:[font = text; inactive; ]

(A.55)  The largest
:[font = input; nowordwrap; ]
$MaxNumber
:[font = text; inactive; ]

(A.56)  and smallest arbitrary-precision numbers,
:[font = input; nowordwrap; ]
$MinNumber
:[font = text; inactive; ]

(A.57)  are much more extreme than the largest
:[font = input; nowordwrap; ]
$MaxMachineNumber
:[font = text; inactive; ]

(A.58)  and smallest floating-point numbers.
:[font = input; nowordwrap; ]
$MinMachineNumber
:[font = text; inactive; ]

(A.59)  Instead of overflowing, large floating-point results are converted 
into arbitrary-precision numbers ...
:[font = input; nowordwrap; ]
$MaxMachineNumber^2
:[font = text; inactive; ]

(A.60)  ... unless the result is too big.
:[font = input; nowordwrap; ]
$MaxMachineNumber ^ $MaxMachineNumber
:[font = text; inactive; ]

(A.62)  Once you have translated heat12.tm into a C program, and compiled the 
program into an executable called "heat12", you can make the "simulate" 
function that it contains accessible to Mathematica.
:[font = input; nowordwrap; ]
Install["heat12"]
:[font = text; inactive; ]

(A.61)  Simulate can then be invoked just as if it were built in to 
Mathematica.
:[font = input; nowordwrap; ]
simulate[1.752, 10., 100., 50., 0., 5., 5]
:[font = text; inactive; ]

(A.63)  Similarly, we can install "heat13" ...
:[font = input; nowordwrap; ]
Install["heat12"]
:[font = text; inactive; ]

(A.64)  ... and invoke its version of "simulate".
:[font = input; nowordwrap; ]
simulate[1.752, 10., 100., 50., 0., 5., 5]
^*)