(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Times New Roman", 24, L0, center, nohscroll, bold;
	fontset = subtitle, "Times New Roman", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Times New Roman", 14, L0, center, nohscroll, bold;
	fontset = section, "Times New Roman", 14, L0, bold, grayBox;
	fontset = subsection, "Times New Roman", 12, L0, bold, blackBox;
	fontset = subsubsection, "Times New Roman", 10, L0, bold, whiteBox;
	fontset = text, "Times New Roman", 12, L0;
	fontset = smalltext, "Times New Roman", 10, L0;
	fontset = input, "Courier New", 12, L0, nowordwrap, bold;
	fontset = output, "Courier New", 12, L0, nowordwrap;
	fontset = message, "Courier New", 10, L0, nowordwrap, R65535;
	fontset = print, "Courier New", 10, L0, nowordwrap;
	fontset = info, "Courier New", 10, L0, nowordwrap;
	fontset = postscript, "Courier New", 8, L0, nowordwrap;
	fontset = name, "Times New Roman", 10, L0, nohscroll, italic, B65535;
	fontset = header, "Times New Roman", 10, L0, right, nohscroll;
	fontset = footer, "Times New Roman", 10, L0, right, nohscroll;
	fontset = help, "Times New Roman", 10, L0, nohscroll;
	fontset = clipboard, "Times New Roman", 12, L0, nohscroll;
	fontset = completions, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = graphics, "Courier New", 10, L0, nowordwrap, nohscroll;
	fontset = special1, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = special2, "Times New Roman", 12, L0, center, nowordwrap, nohscroll;
	fontset = special3, "Times New Roman", 12, L0, right, nowordwrap, nohscroll;
	fontset = special4, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = special5, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = leftheader, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = leftfooter, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = reserved1, "Courier New", 10, L0, nowordwrap, nohscroll;]
:[font = subsection; inactive; ]
This notebook contains the Mathematica commands from Chapter 5 of Introduction
 to Scientific Programming by Joseph L. Zachary.
:[font = text; inactive; ]

(5.3)   We compute the distance to the horizon using the straightforwad 
approach.
:[font = input; nowordwrap; ]
Sqrt[(2.09*10^7 + 66)^2 - (2.09*10^7)^2]
:[font = text; inactive; ]

(5.4)  We simulate what would happen if Mathematica provided floating-point 
numbers with only four-digit mantissas.  First we add the radius and hill 
height.
:[font = input; nowordwrap; ]
2.09*10^7 + 66.
:[font = text; inactive; ]

(5.5)  Then we round the result to four digits and square it.
:[font = input; nowordwrap; ]
(2.090*10^7)^2
:[font = text; inactive; ]

(5.6)  Next we square the radius.
:[font = input; nowordwrap; ]
(2.09*10^7)^2
:[font = text; inactive; ]

(5.7) We subtract the four-digit version of (5.6) from (5.5).
:[font = input; nowordwrap; ]
4.386*10^14 - 4.386*10^14
:[font = text; inactive; ]

(5.8)  Finally, we take the square root of the result from (5.7), which is 
what Mathematica would have produced as a result if its floating-point numbers
 had four-digit mantissas.
:[font = input; nowordwrap; ]
Sqrt[0]
:[font = text; inactive; ]

(5.11)  Now we simulate what would happen with four-digit mantissas using the 
improved method for computing the distance to the horizon.  First we double 
the radius.
:[font = input; nowordwrap; ]
2 * 2.09*10^7
:[font = text; inactive; ]

(5.12)  Next we multiply this result by the hill's height.
:[font = input; nowordwrap; ]
4.18*10^7 * 66.
:[font = text; inactive; ]

(5.13)  We square the hill's height.
:[font = input; nowordwrap; ]
66.^2
:[font = text; inactive; ]

(5.14)  We add the four-digit versions of the results from (5.12) and (5.13).
:[font = input; nowordwrap; ]
2.759*10^9 + 4356.
:[font = text; inactive; ]

(5.15)  And finally we take the square root.  52530 is what Mathematica would 
have produced as a result if its floating-point numbers had four-digit 
mantissas.
:[font = input; nowordwrap; ]
Sqrt[2.759*10^9]
:[font = text; inactive; ]

(5.16)  This is the distance to the horizon from a 100 foot hill.
:[font = input; nowordwrap; ]
Sqrt[2 * 2.09*10^7 * 100 + 100^2]
:[font = text; inactive; ]

(5.17)  We define a function called "horizon" that encapsulates distance to 
the horizon calculations.
:[font = input; nowordwrap; ]
horizon[R_, h_] := Sqrt[2*R*h + h^2]
:[font = text; inactive; ]

(5.18)  We use "horizon" to compute the distance to the horizon from the top 
of a 100 foot hill.  The answer is the same as in (5.16).
:[font = input; nowordwrap; ]
horizon[2.09*10^7, 100]
:[font = text; inactive; ]

(5.20)  We use "horizon" to compute the distance to the horizon from Kill 
Devil Hill using interval arithmetic.  This is the maximum possible distance
 ...
:[font = input; nowordwrap; ]
horizon[2.095*10^7, 66.5]
:[font = text; inactive; ]

(5.21)  ... and this is the minimum possible distance.
:[font = input; nowordwrap; ]
horizon[2.085*10^7, 65.5]
:[font = text; inactive; ]

(5.23)  We create a programmer-defined function "horizonFast" to calculate the
 distance to the horizon using an algebraically suspect but computationally 
acceptable approximation.
:[font = input; nowordwrap; ]
horizonFast[R_, h_] := Sqrt[2*R*h]
:[font = text; inactive; ]

(5.24)  We use "horizon" to compute the distance to the horizon at high tide
 ...
:[font = input; nowordwrap; ]
horizon[2.09*10^7 + 5, 66 - 5]
:[font = text; inactive; ]

(5.25)  ... and at low tide.
:[font = input; nowordwrap; ]
horizon[2.09*10^7 - 5, 66 + 5]
:[font = text; inactive; ]

(5.26)  We compute the distance to the horizon from Kill Devil Hill when our 
eyepoint is three feet above the summit.
:[font = input; nowordwrap; ]
horizon[2.09*10^7, 69]
^*)