(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Times New Roman", 24, L0, center, nohscroll, bold;
	fontset = subtitle, "Times New Roman", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Times New Roman", 14, L0, center, nohscroll, bold;
	fontset = section, "Times New Roman", 14, L0, bold, grayBox;
	fontset = subsection, "Times New Roman", 12, L0, bold, blackBox;
	fontset = subsubsection, "Times New Roman", 10, L0, bold, whiteBox;
	fontset = text, "Times New Roman", 12, L0;
	fontset = smalltext, "Times New Roman", 10, L0;
	fontset = input, "Courier New", 12, L0, nowordwrap, bold;
	fontset = output, "Courier New", 12, L0, nowordwrap;
	fontset = message, "Courier New", 10, L0, nowordwrap, R65535;
	fontset = print, "Courier New", 10, L0, nowordwrap;
	fontset = info, "Courier New", 10, L0, nowordwrap;
	fontset = postscript, "Courier New", 8, L0, nowordwrap;
	fontset = name, "Times New Roman", 10, L0, nohscroll, italic, B65535;
	fontset = header, "Times New Roman", 10, L0, right, nohscroll;
	fontset = footer, "Times New Roman", 10, L0, right, nohscroll;
	fontset = help, "Times New Roman", 10, L0, nohscroll;
	fontset = clipboard, "Times New Roman", 12, L0, nohscroll;
	fontset = completions, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = graphics, "Courier New", 10, L0, nowordwrap, nohscroll;
	fontset = special1, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = special2, "Times New Roman", 12, L0, center, nowordwrap, nohscroll;
	fontset = special3, "Times New Roman", 12, L0, right, nowordwrap, nohscroll;
	fontset = special4, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = special5, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = leftheader, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = leftfooter, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = reserved1, "Courier New", 10, L0, nowordwrap, nohscroll;]
:[font = subsection; inactive; ]
This notebook contains the Mathematica commands from Chapter 8 of Introduction
 to Scientific Programming by Joseph L. Zachary.
:[font = text; inactive; ]

(8.1)  We record the mass, 
:[font = input; nowordwrap; ]
mass = 4.5*10^6
:[font = text; inactive; ]

(8.2)  maximum power output,
:[font = input; nowordwrap; ]
maxPower = 5.0*10^6
:[font = text; inactive; ]

(8.3) and drag coefficient for the destroyer.
:[font = input; nowordwrap; ]
drag = 5.5*10^3
:[font = text; inactive; ]

(8.4)  We define a symbolic expression that gives the position of the 
destroyer in terms of "t".  We will be ignoring the effects of drag in the 
first part of this notebook.
:[font = input; nowordwrap; ]
pos = .032 * t^2
:[font = text; inactive; ]

(8.5)  We plot the position of the destroyer when it is near the origin.
:[font = input; nowordwrap; ]
Plot[pos, {t, -100, 100}, AxesLabel->{"sec", "m"}]
:[font = text; inactive; ]

(8.6)  We plot the position of the destroyer for positive times.
:[font = input; nowordwrap; ]
Plot[pos, {t, 0, 200}, AxesLabel->{"sec", "m"}]
:[font = text; inactive; ]

(8.8)  The velocity of the destroyer is the first derivative of position.
:[font = input; nowordwrap; ]
vel = D[pos, t]
:[font = text; inactive; ]

(8.9)  The acceleration of the destroyer is the first derivative of velocity.
:[font = input; nowordwrap; ]
acc = D[vel, t]
:[font = text; inactive; ]

(8.10)  The force required to move the destroyer along its trajectory is the 
product of mass and acceleration.
:[font = input; nowordwrap; ]
force = mass * acc
:[font = text; inactive; ]

(8.11)  The power required to move the destroyer along its trajectory is the 
product of force and velocity.
:[font = input; nowordwrap; ]
pow = force * vel
:[font = text; inactive; ]

(8.12)  We plot the power required to move the destroyer when it is close to 
the origin.
:[font = input; nowordwrap; ]
Plot[pow/10^6, {t, -100, 100}, 
     AxesLabel->{"sec", "MW"}]
:[font = text; inactive; ]

(8.13)  We plot the absolute value of the power required to move the destroyer
 when it is close to the origin.
:[font = input; nowordwrap; ]
Plot[Abs[pow]/10^6, {t, -100, 100}, 
     AxesLabel->{"sec", "MW"}]
:[font = text; inactive; ]

(8.14)  We want to solve the equation "Abs[pow] == maxPower" to find the two times at which the maximum power capacity of the destroyer is reached.  Unfortunately, "Solve" can't deal with the "Abs" function.  Instead, we find the negative solution ...
:[font = input; nowordwrap; ]
thresholdA = Solve[-pow == maxPower, t]
:[font = text; inactive; ]

... and the positive solution separately.
:[font = input; nowordwrap; ]
thresholdB = Solve[pow == maxPower, t]
:[font = text; inactive; ]

(8.15)  As a result of the assignment in (8.14), "thresholdA" is a list containing 
one replacement.
:[font = input; nowordwrap; ]
thresholdA
:[font = text; inactive; ]

(8.16)  We can obtain the replacement corresponding to the negative solution
by subscripting "thresholdA" with 1 ...
:[font = input; nowordwrap; ]
thresholdA[[1]]
:[font = text; inactive; ]

(8.17)  ... and the replacement corresponding to the positive solution
by subscripting "thresholdB" with 1.
:[font = input; nowordwrap; ]
thresholdB[[1]]
:[font = text; inactive; ]

(8.18)  We can obtain the speed of the destroyer when it reaches power 
threshold either "by hand" ...
:[font = input; nowordwrap; ]
.064 * 271.267
:[font = text; inactive; ]

(8.19)  ... or by replacing all occurrences of "t" in the "vel" expression 
with the threshold time.
:[font = input; nowordwrap; ]
ReplaceAll[vel, thresholdB[[1]]]
:[font = text; inactive; ]

(8.20)  We create a function "makePower" to calculate the power required, in 
the absence of drag, at any point of time along an arbitrary trajectory.  
Here, "pos" is the trajectory expression (which must be a symbolic expression 
in "t") and "mass" is the mass of the destroyer.  In the body of the function,
 we use the "D" function to determine velocity and acceleration expressions.
:[font = input; nowordwrap; ]
makePower[pos_, mass_] := mass * D[D[pos,t],t] * D[pos,t]
:[font = text; inactive; ]

(8.21)  We use "makePower" to calculate the power required to follow 
trajectory "pos".  As expected, we get the same result as in (8.9).
:[font = input; nowordwrap; ]
pow = makePower[pos, mass]
:[font = text; inactive; ]

(8.22)  We calculate power expressions ...
:[font = input; nowordwrap; ]
pow1 = makePower[.016 * t^2, mass]
:[font = text; inactive; ]

(8.23)  ... corresponding to two new trajectories.
:[font = input; nowordwrap; ]
pow2 = makePower[.002 * t^2, mass]
:[font = text; inactive; ]

(8.24)  We find the times at which power threshold is reached for the first of
 the new trajectories.  First we find the negative solution ...
:[font = input; nowordwrap; ]
threshold1A = Solve[-pow1 == maxPower, t]
:[font = text; inactive; ]

... and then the positive solution.
:[font = input; nowordwrap; ]
threshold1B = Solve[pow1 == maxPower, t]
:[font = text; inactive; ]

(8.25)  We find the velocity corresponding to one of the power thresholds for 
the first of the new trajectories.
:[font = input; nowordwrap; ]
ReplaceAll[D[.016*t^2, t], threshold1B[[1]]]
:[font = text; inactive; ]

(8.26)  We find the negative time at which power threshold is reached for the second 
of the new trajectories ...
:[font = input; nowordwrap; ]
Solve[-pow2 == maxPower, t]
:[font = text; inactive; ]

... and then the positive time.
:[font = input; nowordwrap; ]
Solve[pow == maxPower, t]
:[font = text; inactive; ]

(8.27)  We find the power required to follow a constant-velocity trajectory
(in the absence of drag).
:[font = input; nowordwrap; ]
makePower[v*t, mass]
:[font = text; inactive; ]

(8.28)  This function computes the power expression for a destroyer of the 
given "mass" and "drag" coefficient that is following the trajectory "pos"
(where "pos" must be a symbolic expression in "t").  For the remainder of this 
notebook, we will consider the effects of drag on power requirements.
:[font = input; nowordwrap; ]
makePowerDrag[pos_, mass_, drag_] :=
    (mass * D[D[pos,t],t] + drag * D[pos,t]) *
       D[pos,t]
:[font = text; inactive; ]

(8.29)  We calculate a power expression for a destroyer following our original
 trajectory of .032*t^2.
:[font = input; nowordwrap; ]
pow = makePowerDrag[pos, mass, drag]
:[font = text; inactive; ]

(8.30)  We plot the power consumption calculated in (8.29).
:[font = input; nowordwrap; ]
Plot[pow/10^6, {t, -100, 100},
     AxesLabel->{"sec", "MW"}]
:[font = text; inactive; ]

(8.31)  We find the power in watts required at time t=100 ...
:[font = input; nowordwrap; ]
Abs[ReplaceAll[pow, {t->100}]]
:[font = text; inactive; ]

(8.32)  .. and t=-100 seconds when following the trajectory .032*t^2.
:[font = input; nowordwrap; ]
Abs[ReplaceAll[pow, {t->-100}]]
:[font = text; inactive; ]

(8.33)  We plot the power consumption calculated in (8.30) over a different 
time range than we used in (8.26).
:[font = input; nowordwrap; ]
Plot[pow/10^6, {t, -1000, 200},
     AxesLabel->{"sec", "MW"}]
:[font = text; inactive; ]

(8.34)  We determine the times at which the power threshold is reached when 
following the trajectory from (8.30).
:[font = input; nowordwrap; ]
Solve[pow == maxPower, t]
:[font = text; inactive; ]

(8.35)  We determine the power required to follow a constant-velocity 
trajectory (in the presence of drag).
:[font = input; nowordwrap; ]
constantPower = makePowerDrag[v*t, mass, drag]
:[font = text; inactive; ]

(8.36)  We find the maximum sustainable velocities (in m/sec) for the 
destroyer in the presence of drag.
:[font = input; nowordwrap; ]
Solve[constantPower == maxPower, v]
:[font = text; inactive; ]

(8.38)  We define a piecewise trajectory in which the destroyer begins at a 
rest, moves 10,000 meters, and ends at rest.
:[font = input; nowordwrap; ]
move = Which[t < -500, -5000,
             t < 500, 5000*Sin[Pi*t/1000],
             True, 5000]
:[font = text; inactive; ]

(8.39)  We plot the piecewise trajectory from (8.38).
:[font = input; nowordwrap; ]
Plot[move, {t, -600, 600}, 
     AxesLabel->{"sec", "m"}]
:[font = text; inactive; ]

(8.40)  We calculate the power required to follow the pieceewise trajectory 
from (8.38).
:[font = input; nowordwrap; ]
movePower = makePowerDrag[move, mass, drag]
:[font = text; inactive; ]

(8.41)  We plot the power required to follow the piecewise trajectory from
(8.38).
:[font = input; nowordwrap; ]
Plot[movePower/10^6, {t, -600, 600},
     AxesLabel->{"sec", "MW"}]
^*)