(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      3895,        130]*)
(*NotebookOutlinePosition[      4532,        153]*)
(*  CellTagsIndexPosition[      4488,        149]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "This notebook contains the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " commands from Chapter 15 of ",
  StyleBox["Introduction to Scientific Programming",
    FontSlant->"Italic"],
  " by Joseph L. Zachary."
}], "Subsection"],

Cell["\<\
(15.3)  This formula gives the cross section of the corrugated \
steel sheet discussed in Chapter 15.\
\>", "Text"],

Cell["f = 10 * Sin[Pi*x/10]^2", "Input"],

Cell["\<\
(15.4)  This is the first derivative of the formula from \
(15.3).\
\>", "Text"],

Cell["fprime = D[f, x]", "Input"],

Cell["\<\
(15.11)  The \"Integrate\" function will evaluate indefinite \
integrals.\
\>", "Text"],

Cell["Integrate[Sin[x]+2, x]", "Input"],

Cell["\<\
(15.12)  It will also evaluate definite integrals, if a range is \
associated with the variable of integration.\
\>", "Text"],

Cell["Integrate[Sin[x]+2, {x, 0.0, 8.0}]", "Input"],

Cell["\<\
(15.13)  The \"Integrate\" function works symbolically, and it will \
sometimes fail to evaluate an integral, as in this case. \
\>", "Text"],

Cell["Integrate[Sqrt[1 + fprime^2], {x, 0, 10}]", "Input"],

Cell["\<\
(15.14)  \"NIntegrate\" uses a numerical technique to evaluate \
definite integrals.\
\>", "Text"],

Cell["NIntegrate[Sqrt[1 + fprime^2], {x, 0, 10}]", "Input"],

Cell["(15.15)  We load the \"Integ\" package.", "Text"],

Cell["Needs[\"ISP`Integ`\"]", "Input"],

Cell["(15.16)  This is a simple function to integrate.", "Text"],

Cell["g[x_] := Sin[x] + 2", "Input"],

Cell["\<\
(15.17)  We animate the convergence of the rectangular method as it \
deals with the function sin(x)+2 between 0 and 8.  It generates 5 frames.  In \
the first frame 2 rectangles are used, and in each subsequent frame the \
number of rectrangles doubles.\
\>", "Text"],

Cell["AnimateRectangular[g, 0, 8, 5]", "Input"],

Cell["\<\
(15.23)  We animate the convergence of the trapezoidal method as it \
deals with the function sin(x)+2 between 0 and 8.  It generates 5 frames.  In \
the first frame 2 trapezoids are used, and in each subsequent frame the \
number of trapezoids doubles. \
\>", "Text"],

Cell["AnimateTrapezoidal[g, 0, 8, 5]", "Input"]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{520, 600},
WindowMargins->{{Automatic, 16}, {168, Automatic}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 259, 8, 62, "Subsection"],
Cell[1993, 61, 125, 3, 50, "Text"],
Cell[2121, 66, 40, 0, 27, "Input"],
Cell[2164, 68, 90, 3, 32, "Text"],
Cell[2257, 73, 33, 0, 27, "Input"],
Cell[2293, 75, 97, 3, 32, "Text"],
Cell[2393, 80, 39, 0, 27, "Input"],
Cell[2435, 82, 135, 3, 50, "Text"],
Cell[2573, 87, 51, 0, 27, "Input"],
Cell[2627, 89, 151, 3, 50, "Text"],
Cell[2781, 94, 58, 0, 27, "Input"],
Cell[2842, 96, 108, 3, 32, "Text"],
Cell[2953, 101, 59, 0, 27, "Input"],
Cell[3015, 103, 55, 0, 32, "Text"],
Cell[3073, 105, 38, 0, 27, "Input"],
Cell[3114, 107, 64, 0, 32, "Text"],
Cell[3181, 109, 36, 0, 27, "Input"],
Cell[3220, 111, 278, 5, 68, "Text"],
Cell[3501, 118, 47, 0, 27, "Input"],
Cell[3551, 120, 278, 5, 68, "Text"],
Cell[3832, 127, 47, 0, 27, "Input"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

