(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12916,        447]*)
(*NotebookOutlinePosition[     13571,        471]*)
(*  CellTagsIndexPosition[     13527,        467]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "This notebook contains the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " commands from Chapter 7 of ",
  StyleBox["Introduction to Scientific Programming",
    FontSlant->"Italic"],
  " by Joseph L. Zachary."
}], "Subsection"],

Cell["\<\
(7.7)  We use \"Solve\" to find the two times at which a projectile \
is at ground level.\
\>", "Text"],

Cell["Solve[v*t*Sin[theta] - (1/2)*g*t^2 == 0, t]", "Input"],

Cell["\<\
(7.9)  We create a function \"horizontal\" that returns the \
horizonal position in meters of a projectile \"t\" seconds after it is fired \
with initial speed \"v\" m/sec and initial angle \"theta\" radians.  This \
function ignores what happens when the projectile hits the ground.\
\>", 
  "Text"],

Cell["horizontal[v_, theta_, t_] := v * t * Cos[theta]", "Input"],

Cell["\<\
(7.10)  We create a function \"vertical\" that returns the vertical \
position in meters of a projectile \"t\" seconds after it is fired with \
initial speed \"v\" m/sec and initial angle \"theta\" radians.  This function \
ignores what happens when the projectile hits the ground. \
\>", "Text"],

Cell["\<\
vertical[v_, theta_, t_] := v * t * Sin[theta] - 1/2 * g * t^2\
\>",
   "Input"],

Cell["\<\
(7.11)  We create a function \"duration\" that reports the time in \
seconds that elapses before a projectile fired with initial speed \"v\" m/sec \
and an initial angle \"theta\" radians hits the ground.\
\>", "Text"],

Cell["duration[v_, theta_] := 2 * v * Sin[theta] / g", "Input"],

Cell["\<\
(7.12)  The horizontal position of a projectile fired straight up \
will always be zero.\
\>", "Text"],

Cell["horizontal[100, Pi/2, 10]", "Input"],

Cell["\<\
(7.13)  We calculate the horizontal position after 10 seconds of a \
projectile fired at 45 degrees with a speed of 100 m/sec.\
\>", "Text"],

Cell["horizontal[100, Pi/4, 10]", "Input"],

Cell["\<\
(7.14)  Trigonometric functions such as \"Cos\" give exact answers \
if their parameters are exact multiples of pi.\
\>", "Text"],

Cell["Cos[Pi/4]", "Input"],

Cell["\<\
(7.15)  Even though this result is not completely reduced, it is \
still exact.\
\>", "Text"],

Cell["horizontal[100, Pi/8, 10]", "Input"],

Cell["\<\
(7.16)  We use \"N\" to convert the result from (7.13) into \
floating-point form.\
\>", "Text"],

Cell["N[horizontal[100, Pi/4, 10]]", "Input"],

Cell["\<\
(7.17)  The symbolic constant \"g\" appears in this result because \
\"g\" is used in the implementation of \"vertical\" but is nowhere given a \
value.\
\>", "Text"],

Cell["N[vertical[100, Pi/4, 10]]", "Input"],

Cell["\<\
(7.18)  The symbolic constant \"g\" appears in this result for the \
same reason that it appeared in the result of (7.17).\
\>", "Text"],

Cell["vertical[100, Pi/4, 10]", "Input"],

Cell[TextData[{
  "(7.19)  This illustrates in a bit more detail what happens when the call \
to \"vertical\" from (7.18) is made.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " substitutes 100 for \"v\", Pi/4 for \"theta\", and 10 for \"t\" in the \
body of \"vertical\", which results in the following expression.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " then evaluates the expression as if it had been typed in. "
}], "Text"],

Cell["100 * 10 * Sin[Pi/4] - 1/2 * g * 10^2", "Input"],

Cell["(7.20)  We assign \"g\" a value of 9.8 m/sec/sec.", "Text"],

Cell["g = 9.8", "Input"],

Cell["(7.21)  Now when we repeat (7.17) we get a numerical answer.", "Text"],

Cell["N[vertical[100, Pi/4, 10]]", "Input"],

Cell["\<\
(7.22)  This calculates the duration of the flight of a projectile \
fired at 100 m/sec at an angle of 45 degrees.\
\>", "Text"],

Cell["N[duration[100, Pi/4]]", "Input"],

Cell["\<\
(7.23)  We might have chosen to define \"vertical\" so that \
acceleration due to gravity was coded directly in, instead of using the free \
variable \"g\" as we did in (7.10).\
\>", "Text"],

Cell["\<\
vertical[v_, theta_, t_] := v * t * Sin[theta] - 1/2 * 9.8 * \
t^2\
\>", "Input"],

Cell["\<\
(7.24)  We might also have chosen to define \"vertical\" so that \
acceleration due to gravity was a fourth parameter.\
\>", "Text"],

Cell["\<\
vertical[v_, theta_, t_, g_] := v * t * Sin[theta] - 1/2 * g * \
t^2\
\>", "Input"],

Cell["\<\
(7.25)  We could then have specified gravitational constants other \
than 9.8 as a fourth parameter.\
\>", "Text"],

Cell["N[vertical[100, Pi/4, 10, 4.9]]", "Input"],

Cell["(7.26)  We could also have given \"g\" a default value.", "Text"],

Cell["\<\
vertical[v_, theta_, t_, g_:9.8] := v * t * Sin[theta] - 1/2 * g * \
t^2\
\>", "Input"],

Cell["\<\
   Let's revert to the original definition of \"vertical\" from \
(7.10).\
\>", "Text"],

Cell["\<\
vertical[v_, theta_, t_] := v * t * Sin[theta] - 1/2 * g * t^2\
\>",
   "Input"],

Cell["\<\
(7.27)  Because \"t\" is symbolic, the result here is given in \
terms of \"t\".\
\>", "Text"],

Cell["vertical[100, Pi/4, t]", "Input"],

Cell["\<\
(7.28)  The first parameter to this form of \"Plot\" must be a \
symbolic expression in the independent variable.  This variable is \
identified, and its range specified, by the second parameter.\
\>", "Text"],

Cell["Plot[vertical[100, Pi/4, t], {t, 0, 20}]", "Input"],

Cell["\<\
(7.29)  The plot from (7.26) shows the height of the projectile as \
if it continues falling even after it hits the ground.  Here we specify \
bounds on \"t\" that correspond only to the duration of the projectile's \
flight.\
\>", "Text"],

Cell["\<\
Plot[vertical[100, Pi/4, t],
     {t, 0, 20},
     PlotRange->{0, 260}]\
\>", "Input"],

Cell["\<\
(7.30)  In (7.29), we \"guessed at\" the appropriate bounds to put \
on the vertical axis.  Here, we specify the bounds on the horizonal axis \
exactly, which means that the vertical axis is automatically scaled properly.\
\
\>", "Text"],

Cell["\<\
Plot[vertical[100, Pi/4, t],
     {t, 0, duration[100, Pi/4]}]\
\>", "Input"],

Cell["\<\
(7.31)  We repeat (7.30), but use the \"AxesLabel\" option to label \
the axes.\
\>", "Text"],

Cell["\<\
Plot[vertical[100, Pi/4, t],
     {t, 0, duration[100, Pi/4]},
     AxesLabel->{\"sec\", \"m\"}]\
\>", "Input"],

Cell["(7.32)  This is an example of a list.", "Text"],

Cell["{2+2, 2-2, 2*2, 2/2}", "Input"],

Cell["\<\
(7.33)  The \"Table\" function is useful for building lists.  Here, \
we construct a list of the squares of the odd numbers between 1 and 21.\
\>", 
  "Text"],

Cell["Table[n^2, {n, 1, 21, 2}]", "Input"],

Cell["\<\
(7.34)    We include three different curves in a single plot by \
specifying a list of three different dependent expressions as the first \
parameter to \"Plot\".  Unfortunately, two of the height curves extend below \
the ground. \
\>", "Text"],

Cell["\<\
Plot[{vertical[100, Pi/6, t],
      vertical[100, Pi/4, t],
      vertical[100, Pi/3, t]},
     {t, 0, duration[100, Pi/3]},
     AxesLabel->{\"sec\", \"m\"}]\
\>", "Input"],

Cell["\<\
(7.35)  Here's an alternative way to create the plot from (7.34).  \
We create each of the three curves individually and save them to variables.  \
First, the Pi/6 trajectory ...\
\>", "Text"],

Cell["\<\
plot30 = Plot[vertical[100, Pi/6, t],
              {t, 0, duration[100, Pi/6]}]\
\>", "Input"],

Cell["(7.36)  ... next, the Pi/4 trajectory ...", "Text"],

Cell["\<\
plot45 = Plot[vertical[100, Pi/4, t],
              {t, 0, duration[100, Pi/4]}]\
\>", "Input"],

Cell["(7.37)  ... and last, the Pi/3 trajectory ...", "Text"],

Cell["\<\
plot60 = Plot[vertical[100, Pi/3, t],
              {t, 0, duration[100, Pi/3]}]\
\>", "Input"],

Cell["\<\
(7.38)  ... Finally, we use \"Show\" to compute the trajectories on \
one plot.\
\>", "Text"],

Cell["\<\
Show[{plot30, plot45, plot60},
     AxesLabel->{\"sec\", \"m\"}]\
\>", "Input"],

Cell["\<\
(7.39)  On the same plot, we show the horizontal and vertical \
positions of a projectile fired at 100 m/sec at an angle of 45 degrees.\
\>", 
  "Text"],

Cell["\<\
Plot[{horizontal[100, Pi/4, t],
      vertical[100, Pi/4, t]},
     {t, 0, duration[100, Pi/4]},
     AxesLabel->{\"sec\", \"m\"}]\
\>", "Input"],

Cell["\<\
(7.40)  We create a parametric plot using the dependent expressions \
from (7.39).  We do this by using \"ParametricPlot\" and listing the two \
dependent expressions.  The horizontal position is plotted against the \
horizonal axis, and the vertical position is plotted against the vertical \
axis.  Time does not appear explicitly in the plot.\
\>", "Text"],

Cell["\<\
ParametricPlot[{horizontal[100, Pi/4, t],
                vertical[100, Pi/4, t]},
               {t, 0, duration[100, Pi/4]},
               AxesLabel->{\"m\", \"m\"}]\
\>", "Input"],

Cell["\<\
(7.41)  We put three parametric curves on the same plot.  We create \
the Pi/6 curve ...\
\>", "Text"],

Cell["\<\
pplot30 =
  ParametricPlot[{horizontal[100, Pi/6, t],
                  vertical[100, Pi/6, t]},
                 {t, 0, duration[100, Pi/6]}]\
\>", "Input"],

Cell["(7.42)  ... the Pi/4 curve ...", "Text"],

Cell["\<\
pplot45 =
  ParametricPlot[{horizontal[100, Pi/4, t],
                  vertical[100, Pi/4, t]},
                 {t, 0, duration[100, Pi/4]}]\
\>", "Input"],

Cell["(7.43)  ... and the Pi/3 curve.", "Text"],

Cell["\<\
pplot60 =
  ParametricPlot[{horizontal[100, Pi/3, t],
                  vertical[100, Pi/3, t]},
                 {t, 0, duration[100, Pi/3]}]\
\>", "Input"],

Cell["\<\
(7.44)  Finally we use \"Show\" to combine the three curves.  We \
use the \"AspectRatio\" optional parameter to ensure that the scales of the \
two axes are identical.\
\>", "Text"],

Cell["\<\
Show[{pplot30, pplot45, pplot60},
     AxesLabel->{\"m\", \"m\"},
     AspectRatio->Automatic]\
\>", "Input"],

Cell["\<\
(7.45)  We create a sequence of plots showing how the height of a \
projectile depends on both time and the initial angle of its trajectory.  \
Each plot shows the height of the projectile against time for a particular \
initial angle.  The initial angle varies from 0 degrees in the first plot to \
90 degrees in the last plot.

To animate the 13 plots, double click on the cell bracket that encloses all \
of the plots.  A single plot will replace it.  Double click this plot to \
begin the animation.  You can control the animation with the icons that will \
appear at the bottom of the notebook.\
\>", "Text"],

Cell["\<\
Table[Plot[vertical[100, angle, t],
           {t, 0, duration[100, Pi/2]},
           PlotRange->{0, 550},
           AxesLabel->{\"m\", \"m\"}],
      {angle, 0, Pi/2, Pi/24}]\
\>", "Input"],

Cell[BoxData[""], "Input"],

Cell["\<\
(7.46)  We create an animation showing how the trajectory of a \
projectile depends on both time and the the initial angle of its trajectory.  \
In each frame of the animation, a parametric plot of the projectile's \
position is shown.  During the animation, the initial angle varies from 0 to \
90 degrees.\
\>", "Text"],

Cell["\<\
Table[ParametricPlot[{horizontal[100, angle, t],
                      vertical[100, angle, t]},
                     {t, 0, duration[100, Pi/2]},
                     PlotRange->{{0,1100},{0,550}},
                     AxesLabel->{\"m\", \"m\"}],
      {angle, 0, Pi/2, Pi/24}]
\
\>", "Input"]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{571, 600},
WindowMargins->{{Automatic, 41}, {Automatic, 127}},
Magnification->1
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 258, 8, 62, "Subsection"],
Cell[1992, 61, 113, 3, 32, "Text"],
Cell[2108, 66, 60, 0, 27, "Input"],
Cell[2171, 68, 310, 6, 68, "Text"],
Cell[2484, 76, 65, 0, 27, "Input"],
Cell[2552, 78, 306, 5, 68, "Text"],
Cell[2861, 85, 90, 3, 27, "Input"],
Cell[2954, 90, 228, 4, 50, "Text"],
Cell[3185, 96, 63, 0, 27, "Input"],
Cell[3251, 98, 112, 3, 32, "Text"],
Cell[3366, 103, 42, 0, 27, "Input"],
Cell[3411, 105, 150, 3, 50, "Text"],
Cell[3564, 110, 42, 0, 27, "Input"],
Cell[3609, 112, 139, 3, 50, "Text"],
Cell[3751, 117, 26, 0, 27, "Input"],
Cell[3780, 119, 103, 3, 32, "Text"],
Cell[3886, 124, 42, 0, 27, "Input"],
Cell[3931, 126, 106, 3, 32, "Text"],
Cell[4040, 131, 45, 0, 27, "Input"],
Cell[4088, 133, 176, 4, 50, "Text"],
Cell[4267, 139, 43, 0, 27, "Input"],
Cell[4313, 141, 146, 3, 50, "Text"],
Cell[4462, 146, 40, 0, 27, "Input"],
Cell[4505, 148, 460, 10, 68, "Text"],
Cell[4968, 160, 54, 0, 27, "Input"],
Cell[5025, 162, 65, 0, 32, "Text"],
Cell[5093, 164, 24, 0, 27, "Input"],
Cell[5120, 166, 76, 0, 32, "Text"],
Cell[5199, 168, 43, 0, 27, "Input"],
Cell[5245, 170, 138, 3, 32, "Text"],
Cell[5386, 175, 39, 0, 27, "Input"],
Cell[5428, 177, 200, 4, 50, "Text"],
Cell[5631, 183, 91, 3, 27, "Input"],
Cell[5725, 188, 142, 3, 50, "Text"],
Cell[5870, 193, 93, 3, 27, "Input"],
Cell[5966, 198, 124, 3, 32, "Text"],
Cell[6093, 203, 48, 0, 27, "Input"],
Cell[6144, 205, 71, 0, 32, "Text"],
Cell[6218, 207, 97, 3, 27, "Input"],
Cell[6318, 212, 97, 3, 32, "Text"],
Cell[6418, 217, 90, 3, 27, "Input"],
Cell[6511, 222, 104, 3, 32, "Text"],
Cell[6618, 227, 39, 0, 27, "Input"],
Cell[6660, 229, 219, 4, 50, "Text"],
Cell[6882, 235, 57, 0, 27, "Input"],
Cell[6942, 237, 249, 5, 50, "Text"],
Cell[7194, 244, 96, 4, 57, "Input"],
Cell[7293, 250, 247, 5, 68, "Text"],
Cell[7543, 257, 87, 3, 42, "Input"],
Cell[7633, 262, 103, 3, 32, "Text"],
Cell[7739, 267, 121, 4, 57, "Input"],
Cell[7863, 273, 53, 0, 32, "Text"],
Cell[7919, 275, 37, 0, 27, "Input"],
Cell[7959, 277, 168, 4, 50, "Text"],
Cell[8130, 283, 42, 0, 27, "Input"],
Cell[8175, 285, 255, 5, 68, "Text"],
Cell[8433, 292, 183, 6, 87, "Input"],
Cell[8619, 300, 202, 4, 50, "Text"],
Cell[8824, 306, 105, 3, 42, "Input"],
Cell[8932, 311, 57, 0, 32, "Text"],
Cell[8992, 313, 105, 3, 42, "Input"],
Cell[9100, 318, 61, 0, 32, "Text"],
Cell[9164, 320, 105, 3, 42, "Input"],
Cell[9272, 325, 103, 3, 32, "Text"],
Cell[9378, 330, 89, 3, 42, "Input"],
Cell[9470, 335, 162, 4, 50, "Text"],
Cell[9635, 341, 155, 5, 72, "Input"],
Cell[9793, 348, 369, 6, 86, "Text"],
Cell[10165, 356, 193, 5, 72, "Input"],
Cell[10361, 363, 112, 3, 32, "Text"],
Cell[10476, 368, 167, 5, 72, "Input"],
Cell[10646, 375, 46, 0, 32, "Text"],
Cell[10695, 377, 167, 5, 72, "Input"],
Cell[10865, 384, 47, 0, 32, "Text"],
Cell[10915, 386, 167, 5, 72, "Input"],
Cell[11085, 393, 192, 4, 50, "Text"],
Cell[11280, 399, 119, 4, 57, "Input"],
Cell[11402, 405, 623, 11, 140, "Text"],
Cell[12028, 418, 202, 6, 87, "Input"],
Cell[12233, 426, 26, 0, 27, "Input"],
Cell[12262, 428, 331, 6, 68, "Text"],
Cell[12596, 436, 304, 8, 117, "Input"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

